declare module BA.Ui.Controls {
    /**
     * Enum Contianing the names of the OpenAI actions in HTML Control
     */
    enum HTMLControlOpenAIActions {
        generateTextAI = "generateTextAI",
        changeToneOfVoiceAI = "rephraseAI",
        shortenTextAI = "summarizeAI",
        elongateTextAI = "elongateAI",
        createHeadlineAI = "createHeadlineAI",
        openChatAI = "openChatAI"
    }
    /**
     * Events of the HTML Control
     */
    class HTMLControlEvents {
        private static popUp;
        private static editorTarget;
        private static isFullscreen;
        /**
         * Init mehthod of html control
         * We attach on every ancor tag a onclick function
         * @param s Handle of html control
         * @param e event arguments
         */
        static OnInit(s: BAClientHtmlEditor, e: ASPxClientEventArgs): void;
        static GotFocus(s: BAClientHtmlEditor, e: any): void;
        static LostFocus(s: BAClientHtmlEditor, e: any): void;
        static OnPopUpInit(s: BAClientPopupControl, e: ASPxClientEventArgs): void;
        static OnChanged(s: BAClientHtmlEditor, e: ASPxClientEventArgs): void;
        /**
         * Commands of the context menu and toolbox (no custom tools) in html editor
         */
        static OnCommandExecuting: (s: any, e: any) => void;
        static OnCommandExecuted: (s: BAClientHtmlEditor, e: any) => void;
        /**
         * On custom command. It must be handled
         */
        static OnCustomCommand: (s: BAClientHtmlEditor, e: any) => void;
        static OnDialogInitialized(s: any, e: any): void;
        static OnDialogClosed(s: any, e: any): void;
        static OnHTMLChange(sender: ASPxClientControl, evt: ASPxClientProcessingModeEventArgs): void;
        static SaveState(ctrl: any, state: any): void;
        static RestoreState(ctrl: any, state: any): void;
        static SaveStateMemo(ctrl: any, state: any): void;
        static RestoreStateMemo(ctrl: any, state: any): void;
        /**
         * Reset the height of the html control to either the configured value or fullscreen
         * @param elementName   The name of the HTMLControl element
         * @param delayed       TRUE if we need to delay the reset of the height
         */
        static ResetHeight(s: BAClientHtmlEditor, delayed: boolean): void;
        static OnContextMenuShowing(s: BAClientHtmlEditor, e: any): void;
        /**
         * Set AI related toolbar actions enabled or disabled
         * @param s The HtmlEditor
         */
        static SetToolbarAIItemsEnabled(s: BAClientHtmlEditor): void;
        /**
         * Helper function to recursively remove the nodes between the start and the end of a selection
         * @param startBm The start marker of the selection
         * @param endBm the end marker of the selection
         * @param parentContainers the containers to check
         */
        private static RecursiveRemoveNodes;
        /**
         * Replace content inside the selection without losing the selection (DX does not provide a simple way of doing this)
         * @param s The html editor
         * @param newText The new Text to insert
         * @param saveToUndoHistory control wether the state of the editor should be saved to undo history or not
         */
        static ReplaceSelectionContent(s: BAClientHtmlEditor, newText: string, saveToUndoHistory?: boolean): void;
        /**AI Context Menu Actions*/
        /**
         * Create the context menu for AI specific actions
         * @param s
         * @returns
         */
        static CreateAIContextMenu(s: BAClientHtmlEditor): void;
        /**
         * Replace the selection content in realTime (streamed openAI Response)
         * @param name the name of the calling control
         * @param message the received message
         */
        static ReplaceSelectionContentRealTime(name: string, message: string): void;
        /**
         * Replace the selection content in real time (streamed open AI Response), specific for the headline action
         * @param name The name of the control
         * @param message The received message
         * @param originalSelectionContent string containing the original selection's content
         */
        static ReplaceSelectionContentRealtimeHeadline(name: string, message: string, originalSelectionContent: string): void;
        /**
         * Add the chat dialog action
         * @param s The html editor control
         */
        static OpenAIAdvancedModeDialogAction(s: BAClientHtmlEditor): void;
        /**
         * Add the Generate Text action
         * @param s The html editor control
         */
        static AddGenerateTextAction(s: BAClientHtmlEditor): void;
        /**
         * Add the summarize action
         * @param s The html editor control
         */
        static AddSummarizeAction(s: BAClientHtmlEditor): void;
        /**
         * Add the rephrase action
         * @param s The html editor control
         */
        static AddRephraseAction(s: BAClientHtmlEditor): void;
        /**
         * Add the undo action
         * @param s The HTML editor control
         */
        static AddUndoAction(s: BAClientHtmlEditor): void;
        /**
         * Add the elongate text action
         * @param s The html editor control
         */
        static AddElongateTextAction(s: BAClientHtmlEditor): void;
        /**
         * Add the create headline Action
         * @param s The html editor control
         */
        static AddCreateHeadlineAction(s: BAClientHtmlEditor): void;
        /**
         * Default method in html control to prepare for streaming the ai response
         * @param s
         */
        static PrepareRealtimeOpenAICallInline(s: BAClientHtmlEditor): void;
        /**
         * Default method in html control to handle the end of realtime streaming
         * @param s the html editor
         * @param result The clientcommunication mocel
         */
        static HandleRealTimeOpenAICallFinished(s: BAClientHtmlEditor, result: BA.Ui.Models.OpenAIClientCommunicationModel): void;
        /**
         * Helper function to make a streamed call to open ai
         * @param actionName name of the server action
         * @param s the html editor
         * @param clientCommunicationModel The clientcommunicationModel to use
         * @param liveStreamUpdateAction The action to be called during live update
         * @param customData a string containing additional information passed to the live update function
         * @param prepare The method to prepare for live update
         * @param onDone the Method to be called on done
         */
        static MakeOpenAIAsyncCall(actionName: string, s: BAClientHtmlEditor, clientCommunicationModel: BA.Ui.Models.OpenAIClientCommunicationModel, liveStreamUpdateAction?: string, customData?: string, prepare?: () => void, onDone?: (result: BA.Ui.Models.OpenAIClientCommunicationModel) => void): void;
        /**
         * Get the  selected text
         * @param s The HTMLEditor
         * @returns the selected text
         */
        private static GetSelectedText;
    }
}
