declare module BA.Ui.Pages {
    class PageTools {
        static IsGMapsLoaded: boolean;
        private static _DragAndDropRules;
        private static _DragInProgress;
        private static _AcceptsResults;
        private static _MustSavePageCustomizationsOnLoad;
        /**
         * Adds the given instance of BA.Ui.Widgets.Widget to the page displayed in the current tab, if any.
         *
         * @param widget Instance of BA.Ui.Widgets.Widget to add to the page
         * @param inWidgetCatalogue If the widget is being rendered in the catalogue.
         */
        static AddWidgetToCurrentPage(widget: BA.Ui.Widgets.Widget, inWidgetCatalogue?: boolean): void;
        /**
         * Moves the given instance of BA.Ui.Widgets.Widget to the page's catalogue.
         *
         * @param widget instance of BA.Ui.Widgets.Widget to move to the page's catalogue
         * @param forceRemove if the widget must be removed regardless of its beforeRemoving result
         * @param animate if a remove animation should be shown to the user
         * @param saveCustomizations if the widgets positions should be saved after removing. Do not set this to true if not saving them manually afterwards
         */
        static RemoveWidgetFromCurrentPage(widget: Widgets.Widget, forceRemove?: boolean, animate?: boolean, saveCustomizations?: boolean): void;
        /**
         * Returns the page displayed in the current tab, if any.
         */
        static GetCurrentPage(): Page;
        /**
         * Returns the page with Id equal to the parameter, if any.
         *
         * @param id of the page to look for
         */
        static GetPage(id: BA.Classes.Guid): Page;
        /**
         * Checks if the widget with given id is in the catalogue
         *
         * @param id of the widget to look for
         */
        static IsWidgetInCatalogue(id: Classes.Guid): boolean;
        /**
         * Returns the page with configurationGuid equal to the parameter, if any.
         *
         * @param configId of the page to look for
         */
        static GetPageByConfigurationGuid(configId: BA.Classes.Guid): Page;
        static GetPageParameter(): Widgets.Parameters.WidgetParameterBase;
        /**
         * Returns a string containing the json of the parameter of the page
         */
        static GetAllPageParametersJsonString(): string;
        /**
         * DO NOT USE THIS.
         * Internal function that changes the parameter of the page
         *
         * @param changedBy id of the widget that modified the parameter
         * @param newParameter the new parameter for the page
         * @param onlyIfDifferent Optional, default: true. If set to true it will only change the parameter and trigger the ui event if value is different to the current parameter.
         * @param silent Optional, default: false. If set to true it will not trigger the parameter changed event if the parameter was changed. Set to true if the event is not needed in this call.
         */
        static ChangePageParameter(changedBy: string, newParameter?: BA.Ui.Widgets.Parameters.WidgetParameterBase, onlyIfDifferent?: boolean, silent?: boolean): void;
        /**
         * DO NOT USE THIS.
         * Internal function that triggers the parameter changed event of the page
         *
         * @param changedBy id of the widget that modified the parameter
         * @param newParameter the new parameter for the page
         */
        static TriggerPageParameterChangedEvent(changedBy: string, newParameter?: BA.Ui.Widgets.Parameters.WidgetParameterBase): void;
        /**
         * Returns the BA.Ui.Widgets.Widget in the current page with Id equal to the parameter, if any.
         *
         * @param id of the widget to look for
         */
        static GetWidgetInCurrentPage(id: BA.Classes.Guid): BA.Ui.Widgets.Widget;
        /**
         * Creates a new widget instance with given ID based on a multiinstance widget
         *
         * @param id ID of the instance
         * @param widgetInstanceOf ID of the multi instance widget from which the new instance should be created
         * @returns the new instance
         */
        static CreateWidgetInstanceInCurrentPage(id: BA.Classes.Guid, widgetInstanceOf: BA.Classes.Guid): BA.Ui.Widgets.Widget;
        /**
         * Given an element's JQuery object, if said element is rendered within a widget, this function returns the container widget.
         *
         * @param $element
         */
        static GetContainerWidget<T extends BA.Ui.Widgets.Widget>($element: JQuery): T;
        /**
         * Given an element's JQuery object, if said element is rendered within a widget, this function returns the container widgets JQuery object.
         *
         * @param $element
         */
        static GetContainerWidgetJQ($element: JQuery): JQuery;
        /**
         * Given an element's JQuery object, if said element is rendered within a widget, this function returns true. Otherwise it returns false.
         *
         * @param $element
         */
        static IsInWidget($element: JQuery): boolean;
        /**
         * Initializes the drag and drop in the page.
         */
        static InitDragAndDrop(): void;
        private static CanWidgetBeDropped;
        /**
         * Saves the current distribution of widgets in drag and drop areas
         * in form of page customizations.
         */
        static SavePageCustomizations(async?: boolean): void;
        static DeletePageCustomizationsOfCurrentUser(async?: boolean): void;
        private static GetDragAndDropWidgetLocations;
        /**
         * If calling this method before the page is loaded, the customizations
         * will be saved when initializing the drag and drop in the page.
         */
        static SavePageCustomizationsOnLoad(): void;
        static CheckHeightIncompatibility(widget?: JQuery): void;
        static OnGoogleMapsLoaded(): void;
        /**
         * Function to delete instances of a widget for all users for a specific page or widget set from within the designer
         * @param button the button that was clicked on
         * @param evt the event
         * */
        static DeleteInstancesOfWidget(button: any, evt: ASPxClientButtonClickEventArgs): void;
        static AreParametersEqual(object1: any, object2: any): boolean;
    }
}
