declare module BA.Ui.Widgets {
    /**
     * The ListWidget is able to display a list of data using a client side list. The list uses remote service calls
     * for retrieving data and meta data if needed. Developers may define toolbar items and filters, an action that
     * will be called when an entry is (double-)clicked and actions that may be executed on each of the displayed rows.
     */
    class ListWidget extends Widget {
        /**
         * Initialize the general list widget
         *
         * @param widget List widget
         */
        OnContentLoaded(): void;
        /**
         * Returns the id of the div anchor node. May be overridden by sub classes.
         */
        protected GetControlId(): string;
        /**
         * Returns the JQuery object of the anchor node. May be overridden by sub classes.
         */
        protected GetListContainer(): JQuery;
        /**
         * Creates the create-parameter object, which is needed to construct the list control.
         * This function may be overridden by sub classes.
         */
        protected GetCreateParameters(): BA.Ui.ClientSideControls.List.ListControlCreateParameters;
        /**
         * Creates the widget's ListControl using the given create parameters.
         * This function may be overridden in sub classes.
         * @param createParameters
         */
        protected CreateListControl(createParameters: BA.Ui.ClientSideControls.List.ListControlCreateParameters): BA.Ui.ClientSideControls.List.ListControl | JQueryPromise<BA.Ui.ClientSideControls.List.ListControl>;
        /**
         * Overrides the standard widget refresh function in order to only update the list instead of the whole
         * widget content.
         *
         * @param blockWidget
         * @param async
         */
        Refresh(blockWidget?: boolean, async?: boolean): void;
        /**
         * Initializes the custom filters.
         * The function receives all filters as parameter (which are not used in the base implementation).
         * If you are using custom filters, you will need to override this method in order to prepare everything in the ui.
         */
        protected InitCustomFilters(_: BA.Ui.ClientSideControls.List.ListFilter[]): void;
    }
}
