declare module BA.Ui.Widgets {
    /** Class for Weather Widget */
    class WeatherWidget extends Widget {
        private ViewModel;
        private Geocoder;
        private toolTips;
        Init(): void;
        Unload(tabClosing?: boolean): void;
        /**
         * When the content is loaded this function initializes the map and adds the corresponding markers.
         */
        OnContentLoaded(): void;
        /**
         * Calculates the sunshine minutes for the rest of the day
         * @param weatherData weatherdata of dwd
         * @returns sunshine minutes
         */
        private GetSunshineMinutes;
        /**
         * Calculates the precipitation for the rest of the day
         * @param weatherData weather data of dwd
         * @returns precipitation in millimeters
         */
        private GetPrecipitation;
        /**
         * Calculates the mean wind speed
         * @param weatherData weather data of dwd
         * @returns mean wind speed
         */
        private GetMeanWindSpeed;
        /**
         * Sets an icon's tooltip
         * @param mapWrapper Wrapper where you can find the icon div
         * @param icon Name of the icon class
         */
        private SetIconTooltip;
        /**
         * Gets a LatLng using the Google Maps JS API and stores the info for faster future usage. The found address is given as parameter to the callback function. If no address is found, the callback will be called with null as parameter.
         *
         * @param address String containing the address to search using the Google Maps JS API.
         * @param callback Callback function to be called after the LatLng is retrieved.
         */
        private GetSingleLatLng;
        /**
         * Handles the google exception
         * @param e
         */
        private HandleGoogleException;
        /**
         * If a global google maps error happens the map will be cleared and the state of the widget updated.
         */
        private OnGoogleError;
    }
    /**
     * Weather Widget Model
     */
    class WeatherWidgetViewModel {
        WidgetId: BA.Classes.Guid;
        City: string;
        ErrorText: string;
        ShowAsError: boolean;
        Address: string;
    }
}
